==> ember-0.4.0.tar.bz2: ember-0.4.0/src/components/ogre/SceneManagers/EmberPagingSceneManager/include/OgrePagingLandScapeIntersectionSceneQuery.h <==
/*
-----------------------------------------------------------------------------
This source file is part of OGRE
(Object-oriented Graphics Rendering Engine)
For the latest info, see http://www.ogre3d.org/
 
Copyright  2000-2005 The OGRE Team
Also see acknowledgements in Readme.html
 
This program is free software; you can redistribute it and/or modify it under
the terms of the GNU Lesser General Public License as published by the Free Software
Foundation; either version 2 of the License, or (at your option) any later
version.
 
This program is distributed in the hope that it will be useful, but WITHOUT
ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more details.
 
You should have received a copy of the GNU Lesser General Public License along with
this program; if not, write to the Free Software Foundation, Inc., 59 Temple
Place - Suite 330, Boston, MA 02111-1307, USA, or go to
http://www.gnu.org/copyleft/lesser.txt.
-----------------------------------------------------------------------------
*/
/***************************************************************************
OgrePagingLandScapeIntersectionSceneQuery.h  -  description
-------------------
begin                : Tues July 20, 2004
copyright            : (C) 2004 by Jon Anderson
email                : janders@users.sf.net
***************************************************************************/

#ifndef PagingLandScapeIntersectionSCENEQUERY_H
#define PagingLandScapeIntersectionSCENEQUERY_H

#include "OgrePagingLandScapePrerequisites.h"
#include "OgrePagingLandScapeOctreeIntersectionSceneQuery.h"
#include "OgreSceneManager.h"

namespace Ogre
{

/** PagingLandScapeOctree implementation of IntersectionSceneQuery. */
class _OgrePagingLandScapeExport PagingLandScapeIntersectionSceneQuery : public PagingLandScapeOctreeIntersectionSceneQuery
{
public:
    PagingLandScapeIntersectionSceneQuery(SceneManager* creator);
    virtual ~PagingLandScapeIntersectionSceneQuery(void);

    /** See IntersectionSceneQuery. */
    void execute(IntersectionSceneQueryListener* listener);
};

}

#endif

==> ember-0.4.2.tar.bz2: ember-0.4.2/src/components/ogre/SceneManagers/EmberPagingSceneManager/include/OgrePagingLandScapeIntersectionSceneQuery.h <==
/*
-----------------------------------------------------------------------------
This source file is part of OGRE
(Object-oriented Graphics Rendering Engine)
For the latest info, see http://www.ogre3d.org/
 
Copyright  2000-2006 The OGRE Team
Also see acknowledgements in Readme.html
 
This program is free software; you can redistribute it and/or modify it under
the terms of the GNU Lesser General Public License as published by the Free Software
Foundation; either version 2 of the License, or (at your option) any later
version.
 
This program is distributed in the hope that it will be useful, but WITHOUT
ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more details.
 
You should have received a copy of the GNU Lesser General Public License along with
this program; if not, write to the Free Software Foundation, Inc., 59 Temple
Place - Suite 330, Boston, MA 02111-1307, USA, or go to
http://www.gnu.org/copyleft/lesser.txt.
-----------------------------------------------------------------------------
*/
/***************************************************************************
OgrePagingLandScapeIntersectionSceneQuery.h  -  description
-------------------
begin                : Tues July 20, 2004
copyright            : (C) 2004 by Jon Anderson
email                : janders@users.sf.net
***************************************************************************/

#ifndef PagingLandScapeIntersectionSCENEQUERY_H
#define PagingLandScapeIntersectionSCENEQUERY_H

#include "OgrePagingLandScapePrerequisites.h"
#include "OgrePagingLandScapeOctreeIntersectionSceneQuery.h"
#include "OgreSceneManager.h"

namespace Ogre
{

/** PagingLandScapeOctree implementation of IntersectionSceneQuery. */
class _OgrePagingLandScapeExport PagingLandScapeIntersectionSceneQuery : 
	public PagingLandScapeOctreeIntersectionSceneQuery
{
public:
    PagingLandScapeIntersectionSceneQuery(SceneManager* creator);
    virtual ~PagingLandScapeIntersectionSceneQuery(void);

    /** See IntersectionSceneQuery. */
    void execute(IntersectionSceneQueryListener* listener);
};

}

#endif
